@@ -23,12 +23,16 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "cursor.h"
 #include "effects.h"
 #include "input.h"
+#include <KCoreAddons>
 #include "overlaywindow.h"
 #include "outline.h"
 #include "pointer_input.h"
 #include "scene.h"
 #include "screenedge.h"
 #include "wayland_server.h"
+#include "colorcorrection/manager.h"
+
+#include <KWayland/Server/outputconfiguration_interface.h>
 
 namespace KWin
 {
@@ -37,6 +41,7 @@ Platform::Platform(QObject *parent)
     : QObject(parent)
     , m_eglDisplay(EGL_NO_DISPLAY)
 {
+     m_colorCorrect = new ColorCorrect::Manager(this);
 }
 
 Platform::~Platform()
@@ -115,6 +120,11 @@ void Platform::configurationChangeRequested(KWayland::Server::OutputConfiguratio
 {
     Q_UNUSED(config)
     qCWarning(KWIN_CORE) << "This backend does not support configuration changes.";
+
+    // KCoreAddons needs kwayland's 2b3f9509ac1 to not crash
+    if (KCoreAddons::version() >= QT_VERSION_CHECK(5, 39, 0)) {
+        config->setFailed();
+    }
 }
 
 void Platform::setSoftWareCursor(bool set)
@@ -465,4 +475,14 @@ void Platform::invertScreen()
     }
 }
 
+void Platform::createEffectsHandler(Compositor *compositor, Scene *scene)
+{
+    new EffectsHandlerImpl(compositor, scene);
+}
+
+QString Platform::supportInformation() const
+{
+    return QStringLiteral("Name: %1\n").arg(metaObject()->className());
+}
+
 }
